using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Threading;
using System.Windows.Forms;
using MediaPortal.GUI.Library;
//using MediaPortal.Util;
using MediaPortal.Configuration;
using System.Diagnostics;
using System.IO;
using System.Runtime.InteropServices;

namespace OperaLauncher
{
  public partial class FormSettings : Form
  {
    public string arguments;

    public FormSettings()
    {
      InitializeComponent();
    }


    private void displayDeviceSettings()
    {
      using (MediaPortal.Profile.Settings xmlReader = new MediaPortal.Profile.Settings(Config.GetFile(Config.Dir.Config, "MediaPortal.xml")))
      {

        string Path = xmlReader.GetValueAsString(OperaLauncher.PLUGIN_NAME, "Path", "");
        bool noFullscreen = xmlReader.GetValueAsBool(OperaLauncher.PLUGIN_NAME, "noFullscreen", false);
        bool TouchInferface = xmlReader.GetValueAsBool(OperaLauncher.PLUGIN_NAME, "TouchInferface", false);
        string Arguments = xmlReader.GetValueAsString(OperaLauncher.PLUGIN_NAME, "Arguments", "");
        bool UseZoomWidth = xmlReader.GetValueAsBool(OperaLauncher.PLUGIN_NAME, "UseZoomWidth", false);
        string ZoomWidth = xmlReader.GetValueAsString(OperaLauncher.PLUGIN_NAME, "ZoomWidth", "950");
        bool UseMinFontSize = xmlReader.GetValueAsBool(OperaLauncher.PLUGIN_NAME, "UseMinFontSize", false);
        string MinFontSize = xmlReader.GetValueAsString(OperaLauncher.PLUGIN_NAME, "MinFontSize", "9");
        bool UseCustomUserAgent = xmlReader.GetValueAsBool(OperaLauncher.PLUGIN_NAME, "UseCustomUserAgent", false);
        string CustomUserAgent = xmlReader.GetValueAsString(OperaLauncher.PLUGIN_NAME, "CustomUserAgent", "");
        bool UseButtonForwarding = xmlReader.GetValueAsBool(OperaLauncher.PLUGIN_NAME, "UseButtonForwarding", true);

        imageFileName_Editbox.Text = Path;
        fullscreen_chk.Checked = noFullscreen;
        touchinterface_chk.Checked = TouchInferface;
        customargs_txt.Text = Arguments;
        useButtonForwarding.Checked = UseButtonForwarding;

        widthZoom_txt.Text = ZoomWidth;
        if (UseZoomWidth)
        {
          widthZoom_chk.Checked = true;
          widthZoom_txt.Enabled = true;
        }

        minFontSize_nud.Value = Convert.ToDecimal(MinFontSize);
        if (UseMinFontSize)
        {
          useMinFontsize_chk.Checked = true;
          minFontSize_nud.Enabled = true;
        }

        customUA_txt.Text = CustomUserAgent;
        if (UseCustomUserAgent)
        {
          useCustomUA_chk.Checked = true;
          customUA_txt.Enabled = true;
          setToDesktopUA_btn.Enabled = true;
        }

      }
    }
    private void FormSettings_Load(object sender, EventArgs e)
    {
      displayDeviceSettings();
    }

    public static void Main()
    {
      FormSettings frm = new FormSettings();
      if (frm.ShowDialog() == DialogResult.OK)
      {
      }
    }

    private void buttonOk_Click(object sender, EventArgs e)
    {
      using (MediaPortal.Profile.Settings xmlWriter = new MediaPortal.Profile.Settings(Config.GetFile(Config.Dir.Config, "MediaPortal.xml")))
      {
        xmlWriter.SetValue(OperaLauncher.PLUGIN_NAME, "Path", imageFileName_Editbox.Text);
        xmlWriter.SetValueAsBool(OperaLauncher.PLUGIN_NAME, "noFullscreen", fullscreen_chk.Checked);
        xmlWriter.SetValueAsBool(OperaLauncher.PLUGIN_NAME, "TouchInferface", touchinterface_chk.Checked);
        xmlWriter.SetValue(OperaLauncher.PLUGIN_NAME, "Arguments", customargs_txt.Text);
        xmlWriter.SetValueAsBool(OperaLauncher.PLUGIN_NAME, "UseZoomWidth", widthZoom_chk.Checked);
        xmlWriter.SetValue(OperaLauncher.PLUGIN_NAME, "ZoomWidth", widthZoom_txt.Text);
        xmlWriter.SetValueAsBool(OperaLauncher.PLUGIN_NAME, "UseMinFontSize", useMinFontsize_chk.Checked);
        xmlWriter.SetValue(OperaLauncher.PLUGIN_NAME, "MinFontSize", minFontSize_nud.Value);
        xmlWriter.SetValueAsBool(OperaLauncher.PLUGIN_NAME, "UseCustomUserAgent", useCustomUA_chk.Checked);
        xmlWriter.SetValue(OperaLauncher.PLUGIN_NAME, "CustomUserAgent", customUA_txt.Text);
        xmlWriter.SetValueAsBool(OperaLauncher.PLUGIN_NAME, "UseButtonForwarding", useButtonForwarding.Checked);
      }
    }

    private void imageFileName_Button_Click(object sender, EventArgs e)
    {
      OpenFileDialog fdlg = new OpenFileDialog();
      fdlg.Title = "Select the Opera Mobile Emulator executable";
      fdlg.InitialDirectory = Environment.GetFolderPath(Environment.SpecialFolder.ProgramFiles);
      fdlg.Filter = "Opera Mobile|OperaMobileEmu.exe";
      fdlg.FilterIndex = 2;
      fdlg.RestoreDirectory = true;

      if (fdlg.ShowDialog() == DialogResult.OK)
      {
        imageFileName_Editbox.Text = fdlg.FileName;
      }
    }

    private void test_btn_Click(object sender, EventArgs e)
    {
      arguments = "";
      Process opera = new Process();
      if (!fullscreen_chk.Checked)
        arguments += " -fullscreen";
      if (touchinterface_chk.Checked)
        arguments += " -tabletui";
      else
        arguments += " -notouchwithtouchevents";

      arguments += " "+customargs_txt.Text;

      opera.StartInfo.FileName = imageFileName_Editbox.Text;
      opera.StartInfo.WorkingDirectory = Directory.GetParent(imageFileName_Editbox.Text).FullName;
      opera.StartInfo.Arguments = arguments;

      try
      {
        opera.Start();
      }
      catch (Exception ex)
      {
        MessageBox.Show(ex.Message, "Could not start..");
        Log.Error("Start Opera failed: " + ex.Message);
      }
    }

    private void ApplyOpera_btn_Click(object sender, EventArgs e)
    {
      //make scripts/user.js file
      string operaLocation = Directory.GetParent(imageFileName_Editbox.Text).FullName;
      string scriptsFile = System.IO.Path.Combine(operaLocation, @"opera\user.js");

      // Delete the file if it exists.
      if (File.Exists(scriptsFile))
      {
        File.Delete(scriptsFile);
      }

      // Create the file.
      if (!File.Exists(scriptsFile))
      {
        using (FileStream fs = File.Create(scriptsFile))
        {
        }
      }

      // create a writer and open the file
      TextWriter tw = new StreamWriter(scriptsFile);
      tw.WriteLine("if(" + widthZoom_chk.Checked.ToString().ToLower() + ")");
      tw.WriteLine("{");
      tw.WriteLine("var yourTag=document.createElement('meta');");
      tw.WriteLine("yourTag.name = \"viewport\";");
      tw.WriteLine("yourTag.content = \"width=" + widthZoom_txt.Text + "px;\";");
      tw.WriteLine("document.getElementsByTagName('head')[0].appendChild(yourTag);");
      tw.WriteLine("}");
      tw.Close();

      string OperaIniFile = Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData) + @"\Opera\OperaMobileEmulator\opera.ini";

      if (File.Exists(OperaIniFile))
      {
        IniFile ini = new IniFile(OperaIniFile);

        //write values to opera.ini
        ini.IniWriteValue("User Prefs", "User JavaScript", "1");
        ini.IniWriteValue("User Prefs", "User JavaScript File", scriptsFile);

        if (useMinFontsize_chk.Checked)
          ini.IniWriteValue("User Prefs", "Minimum Font Size", minFontSize_nud.Value.ToString());
        else
          ini.IniWriteValue("User Prefs", "Minimum Font Size", null);

        if (useCustomUA_chk.Checked)
          ini.IniWriteValue("User Prefs", "Custom User-Agent", customUA_txt.Text);
        else
          ini.IniWriteValue("User Prefs", "Custom User-Agent", null);

      }
      else
      {
        MessageBox.Show("Opera Program Data not yet created. Please, press the test button first and try to apply settings again.", "Error Message");
      }
    }

    private void widthZoom_chk_CheckedChanged(object sender, EventArgs e)
    {
      if (widthZoom_chk.Checked)
        widthZoom_txt.Enabled = true;
      else
        widthZoom_txt.Enabled = false;
    }
    private void useMinFontsize_chk_CheckedChanged(object sender, EventArgs e)
    {
      if (useMinFontsize_chk.Checked)
        minFontSize_nud.Enabled = true;
      else
        minFontSize_nud.Enabled = false;
    }
    private void useCustomUA_chk_CheckedChanged(object sender, EventArgs e)
    {
      if (useCustomUA_chk.Checked)
      {
        customUA_txt.Enabled = true;
        setToDesktopUA_btn.Enabled = true;
      }
      else
      {
        customUA_txt.Enabled = false;
        setToDesktopUA_btn.Enabled = false;
      }
    }


    private void downloadLink_Click(object sender, EventArgs e)
    {
      Process.Start("http://www.opera.com/developer/tools/mobile/"); 
    }

    private void openHelp_btn_Click(object sender, EventArgs e)
    {
      Process opera = new Process();
      opera.StartInfo.FileName = imageFileName_Editbox.Text;
      opera.StartInfo.WorkingDirectory = Directory.GetParent(imageFileName_Editbox.Text).FullName;
      opera.StartInfo.Arguments = "-?";
      opera.Start();
    }

    private void setToDesktopUA_Click(object sender, EventArgs e)
    {
      customUA_txt.Text = "Opera/9.80 (Windows NT 6.0; U; en) Presto/2.8.99 Version/11.10";
    }

  }
}